run_node_with_hook

Function run_node_with_hook 

pub async fn run_node_with_hook<E, H>(
    node: &E,
    ctx: NodeContext,
    inputs: PortsIn,
    outputs: PortsOut,
    hook: &H,
) -> Result<()>
Execute a single node through the runtime boundary and report lifecycle events.

Errors

Returns an error if lifecycle observation fails or the node executor reports one.