pub async fn run_node_with_metadata_sink<E, M>(
node: &E,
ctx: NodeContext,
inputs: PortsIn,
outputs: PortsOut,
metadata_sink: Arc<M>,
) -> Result<()>Expand description
Execute a single node through the runtime boundary and collect metadata.
Errors
Returns an error if metadata collection fails or the node executor reports one.