pub async fn run_node_with_observers<E, H, M>(
node: &E,
ctx: NodeContext,
inputs: PortsIn,
outputs: PortsOut,
hook: &H,
metadata_sink: Arc<M>,
) -> Result<()>Expand description
Execute a node and report both lifecycle and metadata observations.
Errors
Returns an error if start observation fails, terminal observation fails after successful execution, or the node executor reports one.